import os


def getDesktopPath():
    try:
        output = os.path.expanduser("~/output")
        os.system("xdg-user-dir DESKTOP > " + output)
        path = open(output).read()
        os.remove(output)
    except Exception as e:
        print(e)
        path = os.path.expanduser("~/Desktop")
    stringList = list(path)
    while stringList[-1] == "\n":
        del stringList[-1]
        path = ""
        for i in stringList:
            path += i
    if os.path.exists(path):
        return path
    else:
        return None


def getMenuPath():
    path = os.path.expanduser("~/.local/share/applications")
    if os.path.exists(path):
        return path
    else:
        path = "/usr/local/share/applications"
        if os.path.exists(path):
            return path
        else:
            return None


class LinuxShortcut:
    def __init__(self, path, name, execFile):
        self.execFile = execFile
        self.name = name
        self.path = os.path.join(path, name) + ".desktop"
        self.file = open(self.path, "w")
        self.file.write("[Desktop Entry]\nType=Application\nName=" + self.name + "\nExec=" + self.execFile + "\n")
        self.attributes = {"Path": None, "Comment": None, "Icon": None, "Categories": None}
    
    def setWorkingDirectory(self, directory):
        self.attributes["Path"] = directory

    def setComment(self, comment):
        self.attributes["Comment"] = comment

    def setIcon(self, pathToIcon):
        self.attributes["Icon"] = pathToIcon
    
    def setCategories(self, categories):
        self.attributes["Categories"] = categories
    
    def save(self):
        for attrib in self.attributes:
            if self.attributes[attrib] != None:
                self.file.write(attrib + "=" + self.attributes[attrib] + "\n")
        self.file.close()



from desktop_file.Args import Args
import desktop_file
import sys
import os


class Main:
    def __init__(self):
        self.helpText = open(os.path.join(os.path.dirname(desktop_file.__file__), "help.txt")).read()
        self.args = Args(sys.argv[1:])
        self.format = self.args.formatArgs()
        command = None
        workpath = None
        comment = None
        icon = None
        categories = None
        for arg in self.format[0]:
            try:
                if arg[0] == "--help":
                    print(self.helpText)
                    self.args.exit()
                if arg[0] == "--exec":
                    command = arg[1][0]
                if arg[0] == "--workpath":
                    workpath = arg[1][0]
                if arg[0] == "--comment":
                    comment = arg[1][0]
                if arg[0] == "--icon":
                    icon = arg[1][0]
                if arg[0] == "--categories":
                    categories = arg[1][0]
            except IndexError:
                print("A parameter must be provided for \"" + arg[0] + "\".")
                self.args.exit()
        if len(self.format[0]) == 0:
            print("no arguments given")
            print("Type \"-h\" or \"--help\" for help.")
            self.args.exit()
        elif len(self.format[1]) == 0:
            print("no files given")
            print("Type \"-h\" or \"--help\" for help.")
            self.args.exit()
        elif len(self.format[1]) > 1:
            print("you can only create one file at once")
            self.args.exit()
        elif command != None:
            shortcut = desktop_file.Shortcut(os.path.dirname(self.format[1][0]), os.path.basename(self.format[1][0].replace(".desktop", "").replace(".lnk", "")), command)
            self.setProp(workpath, shortcut.setWorkingDirectory)
            self.setProp(comment, shortcut.setComment)
            self.setProp(icon, shortcut.setIcon)
            self.setProp(categories, shortcut.setCategories)
            shortcut.save()
        else:
            print("you need to specify an exec")

    def setProp(self, prop, function):
        if prop != None:
            function(prop)


if __name__ == "__main__":
    Main()



from desktop_file.Arg import Arg
import os


class Args:
    def __init__(self, args):
        self.args = args
        self.allArgs = [Arg("-h", "--help", 0),
                        Arg("-e", "--exec", 1),
                        Arg("-w", "--workpath", 1),
                        Arg("-c", "--comment", 1),
                        Arg("-i", "--icon", 1),
                        Arg("-t", "--categories", 1)]
        self.invalidValue = "invalid rarg rvalue"
        self.invalidArg = "invalid argument rarg"
    
    def formatArgs(self):
        formatedArgs = []
        files = []
        count = 0
        argCount = -1
        for arg in self.args:
            argCount += 1
            if count > 0:
                count -= 1
                continue
            found = False
            for maybeArg in self.allArgs:
                if arg == maybeArg.name or arg == maybeArg.shortName:
                    found = True
                    formatedArg = [maybeArg.name, []]
                    try:
                        for i in range(maybeArg.values):
                            formatedArg[1].append(self.args[argCount + i + 1])
                    except IndexError:
                        pass
                    formatedArgs.append(formatedArg)
                    count = maybeArg.values
            if not found:
                files.append(arg)
        return [formatedArgs, files]
    
    def exit(self):
        exit()



import sys

if sys.platform == "linux":
    from desktop_file.LinuxShortcut import LinuxShortcut as Shortcut
    from desktop_file.LinuxShortcut import getMenuPath, getDesktopPath
if sys.platform == "win32":
    from desktop_file.WindowsShortcut import WindowsShortcut as Shortcut
    from desktop_file.WindowsShortcut import getMenuPath, getDesktopPath
